/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type log10f_vec[] = {
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff33333, 0x33333333},	/* nan=f(-1.2)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff30a3d, 0x70a3d70a},	/* nan=f(-1.19)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff2e147, 0xae147ae1},	/* nan=f(-1.18)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff2b851, 0xeb851eb8},	/* nan=f(-1.17)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff28f5c, 0x28f5c28f},	/* nan=f(-1.16)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff26666, 0x66666666},	/* nan=f(-1.15)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff23d70, 0xa3d70a3d},	/* nan=f(-1.14)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff2147a, 0xe147ae14},	/* nan=f(-1.13)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff1eb85, 0x1eb851eb},	/* nan=f(-1.12)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff1c28f, 0x5c28f5c2},	/* nan=f(-1.11)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff19999, 0x99999999},	/* nan=f(-1.1)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff170a3, 0xd70a3d70},	/* nan=f(-1.09)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff147ae, 0x147ae147},	/* nan=f(-1.08)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff11eb8, 0x51eb851e},	/* nan=f(-1.07)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff0f5c2, 0x8f5c28f5},	/* nan=f(-1.06)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff0cccc, 0xcccccccc},	/* nan=f(-1.05)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff0a3d7, 0x0a3d70a3},	/* nan=f(-1.04)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff07ae1, 0x47ae147a},	/* nan=f(-1.03)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff051eb, 0x851eb851},	/* nan=f(-1.02)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff028f5, 0xc28f5c28},	/* nan=f(-1.01)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfefffff, 0xfffffffe},	/* nan=f(-1)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfefae14, 0x7ae147ac},	/* nan=f(-0.99)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfef5c28, 0xf5c28f5a},	/* nan=f(-0.98)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfef0a3d, 0x70a3d708},	/* nan=f(-0.97)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfeeb851, 0xeb851eb6},	/* nan=f(-0.96)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfee6666, 0x66666664},	/* nan=f(-0.95)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfee147a, 0xe147ae12},	/* nan=f(-0.94)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfedc28f, 0x5c28f5c0},	/* nan=f(-0.93)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfed70a3, 0xd70a3d6e},	/* nan=f(-0.92)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfed1eb8, 0x51eb851c},	/* nan=f(-0.91)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfeccccc, 0xccccccca},	/* nan=f(-0.9)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfec7ae1, 0x47ae1478},	/* nan=f(-0.89)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfec28f5, 0xc28f5c26},	/* nan=f(-0.88)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfebd70a, 0x3d70a3d4},	/* nan=f(-0.87)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfeb851e, 0xb851eb82},	/* nan=f(-0.86)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfeb3333, 0x33333330},	/* nan=f(-0.85)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfeae147, 0xae147ade},	/* nan=f(-0.84)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfea8f5c, 0x28f5c28c},	/* nan=f(-0.83)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfea3d70, 0xa3d70a3a},	/* nan=f(-0.82)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe9eb85, 0x1eb851e8},	/* nan=f(-0.81)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe99999, 0x99999996},	/* nan=f(-0.8)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe947ae, 0x147ae144},	/* nan=f(-0.79)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe8f5c2, 0x8f5c28f2},	/* nan=f(-0.78)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe8a3d7, 0x0a3d70a0},	/* nan=f(-0.77)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe851eb, 0x851eb84e},	/* nan=f(-0.76)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe7ffff, 0xfffffffc},	/* nan=f(-0.75)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe7ae14, 0x7ae147aa},	/* nan=f(-0.74)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe75c28, 0xf5c28f58},	/* nan=f(-0.73)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe70a3d, 0x70a3d706},	/* nan=f(-0.72)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe6b851, 0xeb851eb4},	/* nan=f(-0.71)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe66666, 0x66666662},	/* nan=f(-0.7)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe6147a, 0xe147ae10},	/* nan=f(-0.69)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe5c28f, 0x5c28f5be},	/* nan=f(-0.68)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe570a3, 0xd70a3d6c},	/* nan=f(-0.67)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe51eb8, 0x51eb851a},	/* nan=f(-0.66)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe4cccc, 0xccccccc8},	/* nan=f(-0.65)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe47ae1, 0x47ae1476},	/* nan=f(-0.64)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe428f5, 0xc28f5c24},	/* nan=f(-0.63)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe3d70a, 0x3d70a3d2},	/* nan=f(-0.62)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe3851e, 0xb851eb80},	/* nan=f(-0.61)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe33333, 0x3333332e},	/* nan=f(-0.6)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe2e147, 0xae147adc},	/* nan=f(-0.59)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe28f5c, 0x28f5c28a},	/* nan=f(-0.58)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe23d70, 0xa3d70a38},	/* nan=f(-0.57)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe1eb85, 0x1eb851e6},	/* nan=f(-0.56)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe19999, 0x99999994},	/* nan=f(-0.55)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe147ae, 0x147ae142},	/* nan=f(-0.54)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe0f5c2, 0x8f5c28f0},	/* nan=f(-0.53)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe0a3d7, 0x0a3d709e},	/* nan=f(-0.52)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfe051eb, 0x851eb84c},	/* nan=f(-0.51)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfdfffff, 0xfffffff4},	/* nan=f(-0.5)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfdf5c28, 0xf5c28f50},	/* nan=f(-0.49)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfdeb851, 0xeb851eac},	/* nan=f(-0.48)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfde147a, 0xe147ae08},	/* nan=f(-0.47)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfdd70a3, 0xd70a3d64},	/* nan=f(-0.46)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfdccccc, 0xccccccc0},	/* nan=f(-0.45)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfdc28f5, 0xc28f5c1c},	/* nan=f(-0.44)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfdb851e, 0xb851eb78},	/* nan=f(-0.43)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfdae147, 0xae147ad4},	/* nan=f(-0.42)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfda3d70, 0xa3d70a30},	/* nan=f(-0.41)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd99999, 0x9999998c},	/* nan=f(-0.4)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd8f5c2, 0x8f5c28e8},	/* nan=f(-0.39)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd851eb, 0x851eb844},	/* nan=f(-0.38)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd7ae14, 0x7ae147a0},	/* nan=f(-0.37)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd70a3d, 0x70a3d6fc},	/* nan=f(-0.36)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd66666, 0x66666658},	/* nan=f(-0.35)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd5c28f, 0x5c28f5b4},	/* nan=f(-0.34)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd51eb8, 0x51eb8510},	/* nan=f(-0.33)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd47ae1, 0x47ae146c},	/* nan=f(-0.32)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd3d70a, 0x3d70a3c8},	/* nan=f(-0.31)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd33333, 0x33333324},	/* nan=f(-0.3)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd28f5c, 0x28f5c280},	/* nan=f(-0.29)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd1eb85, 0x1eb851dc},	/* nan=f(-0.28)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd147ae, 0x147ae138},	/* nan=f(-0.27)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfd0a3d7, 0x0a3d7094},	/* nan=f(-0.26)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfcfffff, 0xffffffe0},	/* nan=f(-0.25)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfceb851, 0xeb851e98},	/* nan=f(-0.24)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfcd70a3, 0xd70a3d50},	/* nan=f(-0.23)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfcc28f5, 0xc28f5c08},	/* nan=f(-0.22)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfcae147, 0xae147ac0},	/* nan=f(-0.21)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfc99999, 0x99999978},	/* nan=f(-0.2)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfc851eb, 0x851eb830},	/* nan=f(-0.19)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfc70a3d, 0x70a3d6e8},	/* nan=f(-0.18)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfc5c28f, 0x5c28f5a0},	/* nan=f(-0.17)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfc47ae1, 0x47ae1458},	/* nan=f(-0.16)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfc33333, 0x33333310},	/* nan=f(-0.15)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfc1eb85, 0x1eb851c8},	/* nan=f(-0.14)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfc0a3d7, 0x0a3d7080},	/* nan=f(-0.13)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfbeb851, 0xeb851e71},	/* nan=f(-0.12)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfbc28f5, 0xc28f5be2},	/* nan=f(-0.11)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfb99999, 0x99999953},	/* nan=f(-0.1)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfb70a3d, 0x70a3d6c4},	/* nan=f(-0.09)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfb47ae1, 0x47ae1435},	/* nan=f(-0.08)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfb1eb85, 0x1eb851a6},	/* nan=f(-0.07)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfaeb851, 0xeb851e2d},	/* nan=f(-0.06)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfa99999, 0x9999990e},	/* nan=f(-0.05)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbfa47ae1, 0x47ae13ef},	/* nan=f(-0.04)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbf9eb851, 0xeb851da0},	/* nan=f(-0.03)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbf947ae1, 0x47ae1362},	/* nan=f(-0.02)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbf847ae1, 0x47ae1249},	/* nan=f(-0.01)*/
{32, 0,123,__LINE__, 0xc02e05a6, 0x2c6e0cb1, 0x3cd19000, 0x00000000},	/* -15.011=f(9.74915e-16)*/
{32, 0,123,__LINE__, 0xc0000000, 0x014d89c5, 0x3f847ae1, 0x47ae16ad},	/* -2=f(0.01)*/
{32, 0,123,__LINE__, 0xbffb2efb, 0x2e73350b, 0x3f947ae1, 0x47ae1594},	/* -1.69897=f(0.02)*/
{32, 0,123,__LINE__, 0xbff85db6, 0x1d071e0b, 0x3f9eb851, 0xeb851fd2},	/* -1.52288=f(0.03)*/
{32, 0,123,__LINE__, 0xbff65df6, 0x5a4b568b, 0x3fa47ae1, 0x47ae1508},	/* -1.39794=f(0.04)*/
{32, 0,123,__LINE__, 0xbff4d104, 0xd26b26cf, 0x3fa99999, 0x99999a27},	/* -1.30103=f(0.05)*/
{32, 0,123,__LINE__, 0xbff38cb1, 0x48df3f8b, 0x3faeb851, 0xeb851f46},	/* -1.22185=f(0.06)*/
{32, 0,123,__LINE__, 0xbff27a7a, 0x79c489f7, 0x3fb1eb85, 0x1eb85232},	/* -1.1549=f(0.07)*/
{32, 0,123,__LINE__, 0xbff18cf1, 0x8623780b, 0x3fb47ae1, 0x47ae14c1},	/* -1.09691=f(0.08)*/
{32, 0,123,__LINE__, 0xbff0bb6c, 0x30362b2a, 0x3fb70a3d, 0x70a3d750},	/* -1.04576=f(0.09)*/
{32, 0,123,__LINE__, 0xbfefffff, 0xfc86909e, 0x3fb99999, 0x999999df},	/* -1=f(0.1)*/
{32, 0,123,__LINE__, 0xbfeeace9, 0x40a1e375, 0x3fbc28f5, 0xc28f5c6e},	/* -0.958607=f(0.11)*/
{32, 0,123,__LINE__, 0xbfed7758, 0xe96ec217, 0x3fbeb851, 0xeb851efd},	/* -0.920819=f(0.12)*/
{32, 0,123,__LINE__, 0xbfec5a93, 0x81153c57, 0x3fc0a3d7, 0x0a3d70c6},	/* -0.886057=f(0.13)*/
{32, 0,123,__LINE__, 0xbfeb52eb, 0x4b3956ee, 0x3fc1eb85, 0x1eb8520e},	/* -0.853872=f(0.14)*/
{32, 0,123,__LINE__, 0xbfea5d75, 0xd3e3fe52, 0x3fc33333, 0x33333356},	/* -0.823909=f(0.15)*/
{32, 0,123,__LINE__, 0xbfe977d9, 0x63f73317, 0x3fc47ae1, 0x47ae149e},	/* -0.79588=f(0.16)*/
{32, 0,123,__LINE__, 0xbfe8a029, 0x92f52eaa, 0x3fc5c28f, 0x5c28f5e6},	/* -0.769551=f(0.17)*/
{32, 0,123,__LINE__, 0xbfe7d4ce, 0xb81c9955, 0x3fc70a3d, 0x70a3d72e},	/* -0.744727=f(0.18)*/
{32, 0,123,__LINE__, 0xbfe71473, 0x56f57d5b, 0x3fc851eb, 0x851eb876},	/* -0.721246=f(0.19)*/
{32, 0,123,__LINE__, 0xbfe65df6, 0x5436d39e, 0x3fc99999, 0x999999be},	/* -0.69897=f(0.2)*/
{32, 0,123,__LINE__, 0xbfe5b061, 0x30a6dcd0, 0x3fcae147, 0xae147b06},	/* -0.677781=f(0.21)*/
{32, 0,123,__LINE__, 0xbfe50adf, 0x98522676, 0x3fcc28f5, 0xc28f5c4e},	/* -0.657577=f(0.22)*/
{32, 0,123,__LINE__, 0xbfe46cb9, 0xba8d42a0, 0x3fcd70a3, 0xd70a3d96},	/* -0.638272=f(0.23)*/
{32, 0,123,__LINE__, 0xbfe3d54f, 0x411f0518, 0x3fceb851, 0xeb851ede},	/* -0.619789=f(0.24)*/
{32, 0,123,__LINE__, 0xbfe34413, 0x509f79ff, 0x3fd00000, 0x00000013},	/* -0.60206=f(0.25)*/
{32, 0,123,__LINE__, 0xbfe2b889, 0xd8c57f58, 0x3fd0a3d7, 0x0a3d70b7},	/* -0.585027=f(0.26)*/
{32, 0,123,__LINE__, 0xbfe23244, 0x95446b56, 0x3fd147ae, 0x147ae15b},	/* -0.568636=f(0.27)*/
{32, 0,123,__LINE__, 0xbfe1b0e1, 0xa2e999ef, 0x3fd1eb85, 0x1eb851ff},	/* -0.552842=f(0.28)*/
{32, 0,123,__LINE__, 0xbfe13409, 0x23debfd2, 0x3fd28f5c, 0x28f5c2a3},	/* -0.537602=f(0.29)*/
{32, 0,123,__LINE__, 0xbfe0bb6c, 0x2b944153, 0x3fd33333, 0x33333347},	/* -0.522879=f(0.3)*/
{32, 0,123,__LINE__, 0xbfe046c3, 0xd5842001, 0x3fd3d70a, 0x3d70a3eb},	/* -0.508638=f(0.31)*/
{32, 0,123,__LINE__, 0xbfdfab9f, 0x774eec2f, 0x3fd47ae1, 0x47ae148f},	/* -0.49485=f(0.32)*/
{32, 0,123,__LINE__, 0xbfded0aa, 0xd5e56ceb, 0x3fd51eb8, 0x51eb8533},	/* -0.481486=f(0.33)*/
{32, 0,123,__LINE__, 0xbfddfc3f, 0xd54ae356, 0x3fd5c28f, 0x5c28f5d7},	/* -0.468521=f(0.34)*/
{32, 0,123,__LINE__, 0xbfdd2dfd, 0x419ee01a, 0x3fd66666, 0x6666667b},	/* -0.455932=f(0.35)*/
{32, 0,123,__LINE__, 0xbfdc658a, 0x1f99b8ab, 0x3fd70a3d, 0x70a3d71f},	/* -0.443697=f(0.36)*/
{32, 0,123,__LINE__, 0xbfdba295, 0x36640286, 0x3fd7ae14, 0x7ae147c3},	/* -0.431798=f(0.37)*/
{32, 0,123,__LINE__, 0xbfdae4d3, 0x5d4b80b7, 0x3fd851eb, 0x851eb867},	/* -0.420216=f(0.38)*/
{32, 0,123,__LINE__, 0xbfda2bff, 0x6bdaa2b1, 0x3fd8f5c2, 0x8f5c290b},	/* -0.408935=f(0.39)*/
{32, 0,123,__LINE__, 0xbfd977d9, 0x57ce2d3e, 0x3fd99999, 0x999999af},	/* -0.39794=f(0.4)*/
{32, 0,123,__LINE__, 0xbfd8c826, 0x3c0918d5, 0x3fda3d70, 0xa3d70a53},	/* -0.387216=f(0.41)*/
{32, 0,123,__LINE__, 0xbfd81caf, 0x10ae3fa1, 0x3fdae147, 0xae147af7},	/* -0.376751=f(0.42)*/
{32, 0,123,__LINE__, 0xbfd77540, 0xb14d84fc, 0x3fdb851e, 0xb851eb9b},	/* -0.366532=f(0.43)*/
{32, 0,123,__LINE__, 0xbfd6d1ab, 0xe004d2ed, 0x3fdc28f5, 0xc28f5c3f},	/* -0.356547=f(0.44)*/
{32, 0,123,__LINE__, 0xbfd631c4, 0x305a3d9f, 0x3fdccccc, 0xcccccce3},	/* -0.346787=f(0.45)*/
{32, 0,123,__LINE__, 0xbfd59560, 0x247b0b42, 0x3fdd70a3, 0xd70a3d87},	/* -0.337242=f(0.46)*/
{32, 0,123,__LINE__, 0xbfd4fc59, 0x454bdedc, 0x3fde147a, 0xe147ae2b},	/* -0.327902=f(0.47)*/
{32, 0,123,__LINE__, 0xbfd4668b, 0x319e9031, 0x3fdeb851, 0xeb851ecf},	/* -0.318759=f(0.48)*/
{32, 0,123,__LINE__, 0xbfd3d3d3, 0xc90962e9, 0x3fdf5c28, 0xf5c28f73},	/* -0.309804=f(0.49)*/
{32, 0,123,__LINE__, 0xbfd34413, 0x509f79ff, 0x3fe00000, 0x0000000b},	/* -0.30103=f(0.5)*/
{32, 0,123,__LINE__, 0xbfd2b72b, 0x9d3a826d, 0x3fe051eb, 0x851eb85d},	/* -0.29243=f(0.51)*/
{32, 0,123,__LINE__, 0xbfd22d00, 0x60eb84b0, 0x3fe0a3d7, 0x0a3d70af},	/* -0.283997=f(0.52)*/
{32, 0,123,__LINE__, 0xbfd1a576, 0xebde4c80, 0x3fe0f5c2, 0x8f5c2901},	/* -0.275724=f(0.53)*/
{32, 0,123,__LINE__, 0xbfd12075, 0xd9e95cad, 0x3fe147ae, 0x147ae153},	/* -0.267606=f(0.54)*/
{32, 0,123,__LINE__, 0xbfd09de5, 0xc540f1b3, 0x3fe19999, 0x999999a5},	/* -0.259637=f(0.55)*/
{32, 0,123,__LINE__, 0xbfd01daf, 0xf533b9df, 0x3fe1eb85, 0x1eb851f7},	/* -0.251812=f(0.56)*/
{32, 0,123,__LINE__, 0xbfcf3f7e, 0x2f364972, 0x3fe23d70, 0xa3d70a49},	/* -0.244125=f(0.57)*/
{32, 0,123,__LINE__, 0xbfce47fd, 0xee3c0b48, 0x3fe28f5c, 0x28f5c29b},	/* -0.236572=f(0.58)*/
{32, 0,123,__LINE__, 0xbfcd54b8, 0xcf6d6447, 0x3fe2e147, 0xae147aed},	/* -0.229148=f(0.59)*/
{32, 0,123,__LINE__, 0xbfcc658a, 0x0d12114e, 0x3fe33333, 0x3333333f},	/* -0.221849=f(0.6)*/
{32, 0,123,__LINE__, 0xbfcb7a4f, 0xc7280f6b, 0x3fe3851e, 0xb851eb91},	/* -0.21467=f(0.61)*/
{32, 0,123,__LINE__, 0xbfca92e8, 0xb4d18c05, 0x3fe3d70a, 0x3d70a3e3},	/* -0.207608=f(0.62)*/
{32, 0,123,__LINE__, 0xbfc9af35, 0x7fec9242, 0x3fe428f5, 0xc28f5c35},	/* -0.200659=f(0.63)*/
{32, 0,123,__LINE__, 0xbfc8cf18, 0x4d5ee460, 0x3fe47ae1, 0x47ae1487},	/* -0.19382=f(0.64)*/
{32, 0,123,__LINE__, 0xbfc7f274, 0xa593e55a, 0x3fe4cccc, 0xccccccd9},	/* -0.187087=f(0.65)*/
{32, 0,123,__LINE__, 0xbfc7192f, 0x0a8be5d9, 0x3fe51eb8, 0x51eb852b},	/* -0.180456=f(0.66)*/
{32, 0,123,__LINE__, 0xbfc6432e, 0x35f19219, 0x3fe570a3, 0xd70a3d7d},	/* -0.173925=f(0.67)*/
{32, 0,123,__LINE__, 0xbfc57059, 0x0956d2ad, 0x3fe5c28f, 0x5c28f5cf},	/* -0.167491=f(0.68)*/
{32, 0,123,__LINE__, 0xbfc4a097, 0xd1b983c5, 0x3fe6147a, 0xe147ae21},	/* -0.161151=f(0.69)*/
{32, 0,123,__LINE__, 0xbfc3d3d3, 0xe1fecc36, 0x3fe66666, 0x66666673},	/* -0.154902=f(0.7)*/
{32, 0,123,__LINE__, 0xbfc309f7, 0x8416b054, 0x3fe6b851, 0xeb851ec5},	/* -0.148742=f(0.71)*/
{32, 0,123,__LINE__, 0xbfc242ed, 0x9df47d58, 0x3fe70a3d, 0x70a3d717},	/* -0.142667=f(0.72)*/
{32, 0,123,__LINE__, 0xbfc17ea2, 0xda942215, 0x3fe75c28, 0xf5c28f69},	/* -0.136677=f(0.73)*/
{32, 0,123,__LINE__, 0xbfc0bd03, 0xcb89110f, 0x3fe7ae14, 0x7ae147bb},	/* -0.130768=f(0.74)*/
{30, 0,123,__LINE__, 0xbfbffbfc, 0x2bbc7803, 0x3fe80000, 0x0000000d},	/* -0.124939=f(0.75)*/
{32, 0,123,__LINE__, 0xbfbe8300, 0x32b01ae0, 0x3fe851eb, 0x851eb85f},	/* -0.119186=f(0.76)*/
{32, 0,123,__LINE__, 0xbfbd0ef1, 0xcd619c12, 0x3fe8a3d7, 0x0a3d70b1},	/* -0.113509=f(0.77)*/
{32, 0,123,__LINE__, 0xbfbb9fb0, 0x6ceca2c8, 0x3fe8f5c2, 0x8f5c2903},	/* -0.107905=f(0.78)*/
{32, 0,123,__LINE__, 0xbfba351c, 0x343d6ba4, 0x3fe947ae, 0x147ae155},	/* -0.102373=f(0.79)*/
{32, 0,123,__LINE__, 0xbfb8cf18, 0x1cbaccfb, 0x3fe99999, 0x999999a7},	/* -0.09691=f(0.8)*/
{32, 0,123,__LINE__, 0xbfb76d86, 0x95851942, 0x3fe9eb85, 0x1eb851f9},	/* -0.091515=f(0.81)*/
{32, 0,123,__LINE__, 0xbfb6104b, 0xada67b57, 0x3fea3d70, 0xa3d70a4b},	/* -0.0861862=f(0.82)*/
{32, 0,123,__LINE__, 0xbfb4b74c, 0x7847ef50, 0x3fea8f5c, 0x28f5c29d},	/* -0.0809219=f(0.83)*/
{32, 0,123,__LINE__, 0xbfb3626f, 0x003b1687, 0x3feae147, 0xae147aef},	/* -0.0757207=f(0.84)*/
{32, 0,123,__LINE__, 0xbfb21199, 0xb97435f5, 0x3feb3333, 0x33333341},	/* -0.0705811=f(0.85)*/
{32, 0,123,__LINE__, 0xbfb0c4b5, 0x82b82bf3, 0x3feb851e, 0xb851eb93},	/* -0.0655015=f(0.86)*/
{32, 0,123,__LINE__, 0xbfaef755, 0x0ba2726a, 0x3febd70a, 0x3d70a3e5},	/* -0.0604807=f(0.87)*/
{32, 0,123,__LINE__, 0xbfac6cc4, 0x7b2ac76f, 0x3fec28f5, 0xc28f5c37},	/* -0.0555173=f(0.88)*/
{32, 0,123,__LINE__, 0xbfa9e98d, 0xd0956b78, 0x3fec7ae1, 0x47ae1489},	/* -0.05061=f(0.89)*/
{32, 0,123,__LINE__, 0xbfa76d86, 0xfdd61d02, 0x3feccccc, 0xccccccdb},	/* -0.0457575=f(0.9)*/
{32, 0,123,__LINE__, 0xbfa4f886, 0x656d540b, 0x3fed1eb8, 0x51eb852d},	/* -0.0409586=f(0.91)*/
{32, 0,123,__LINE__, 0xbfa28a66, 0x9edc8a18, 0x3fed70a3, 0xd70a3d7f},	/* -0.0362122=f(0.92)*/
{32, 0,123,__LINE__, 0xbfa02300, 0xa5c35025, 0x3fedc28f, 0x5c28f5d1},	/* -0.031517=f(0.93)*/
{32, 0,123,__LINE__, 0xbf9b845f, 0x4ac64dcc, 0x3fee147a, 0xe147ae23},	/* -0.0268721=f(0.94)*/
{32, 0,123,__LINE__, 0xbf96cf9f, 0xe8a74b4c, 0x3fee6666, 0x66666675},	/* -0.0222764=f(0.95)*/
{32, 0,123,__LINE__, 0xbf92277e, 0x0ff16322, 0x3feeb851, 0xeb851ec7},	/* -0.0177288=f(0.96)*/
{32, 0,123,__LINE__, 0xbf8b176a, 0x0d8a97e9, 0x3fef0a3d, 0x70a3d719},	/* -0.0132283=f(0.97)*/
{32, 0,123,__LINE__, 0xbf81f80f, 0x0d3d1d43, 0x3fef5c28, 0xf5c28f6b},	/* -0.00877392=f(0.98)*/
{32, 0,123,__LINE__, 0xbf71e0d3, 0x67d110df, 0x3fefae14, 0x7ae147bd},	/* -0.0043648=f(0.99)*/
{32, 0,123,__LINE__, 0x00000000, 0x00000000, 0x3ff00000, 0x00000007},	/* 0=f(1)*/
{32, 0,123,__LINE__, 0x3f71b348, 0xd75298ec, 0x3ff028f5, 0xc28f5c30},	/* 0.00432137=f(1.01)*/
{32, 0,123,__LINE__, 0x3f819cf6, 0x6c9ef240, 0x3ff051eb, 0x851eb859},	/* 0.00860016=f(1.02)*/
{32, 0,123,__LINE__, 0x3f8a4a65, 0x83bf3586, 0x3ff07ae1, 0x47ae1482},	/* 0.0128372=f(1.03)*/
{32, 0,123,__LINE__, 0x3f91712e, 0xfb3f54ed, 0x3ff0a3d7, 0x0a3d70ab},	/* 0.0170333=f(1.04)*/
{32, 0,123,__LINE__, 0x3f95b2a4, 0x774a2de2, 0x3ff0cccc, 0xccccccd4},	/* 0.0211893=f(1.05)*/
{32, 0,123,__LINE__, 0x3f99e9c6, 0x4c12d7f5, 0x3ff0f5c2, 0x8f5c28fd},	/* 0.0253058=f(1.06)*/
{32, 0,123,__LINE__, 0x3f9e16c9, 0x5e833c9d, 0x3ff11eb8, 0x51eb8526},	/* 0.0293838=f(1.07)*/
{32, 0,123,__LINE__, 0x3fa11ceb, 0xb5b0ea92, 0x3ff147ae, 0x147ae14f},	/* 0.0334238=f(1.08)*/
{32, 0,123,__LINE__, 0x3fa32991, 0x538e942d, 0x3ff170a3, 0xd70a3d78},	/* 0.0374265=f(1.09)*/
{32, 0,123,__LINE__, 0x3fa5316c, 0x5af4425e, 0x3ff19999, 0x999999a1},	/* 0.0413927=f(1.1)*/
{32, 0,123,__LINE__, 0x3fa73492, 0xff5e9bb6, 0x3ff1c28f, 0x5c28f5ca},	/* 0.045323=f(1.11)*/
{32, 0,123,__LINE__, 0x3fa9331a, 0xdb5e0101, 0x3ff1eb85, 0x1eb851f3},	/* 0.049218=f(1.12)*/
{32, 0,123,__LINE__, 0x3fab2d18, 0xf6068920, 0x3ff2147a, 0xe147ae1c},	/* 0.0530784=f(1.13)*/
{32, 0,123,__LINE__, 0x3fad22a1, 0xc822aa32, 0x3ff23d70, 0xa3d70a45},	/* 0.0569048=f(1.14)*/
{32, 0,123,__LINE__, 0x3faf13c9, 0x412bc69a, 0x3ff26666, 0x6666666e},	/* 0.0606978=f(1.15)*/
{32, 0,123,__LINE__, 0x3fb08051, 0x6605d16b, 0x3ff28f5c, 0x28f5c297},	/* 0.064458=f(1.16)*/
{32, 0,123,__LINE__, 0x3fb174a0, 0xa9d4cd30, 0x3ff2b851, 0xeb851ec0},	/* 0.0681858=f(1.17)*/
{32, 0,123,__LINE__, 0x3fb266db, 0xa3a31f6e, 0x3ff2e147, 0xae147ae9},	/* 0.071882=f(1.18)*/
{32, 0,123,__LINE__, 0x3fb3570c, 0x0a2f1c5b, 0x3ff30a3d, 0x70a3d712},	/* 0.075547=f(1.19)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc01921fb, 0x54442d18},	/* nan=f(-6.28319)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc012d97c, 0x7f3321d2},	/* nan=f(-4.71239)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc00921fb, 0x54442d18},	/* nan=f(-3.14159)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff921fb, 0x54442d18},	/* nan=f(-1.5708)*/
{32, 0, 34,__LINE__, 0xfff00000, 0x00000000, 0x00000000, 0x00000000},	/* -inf=f(0)*/
{32, 0,123,__LINE__, 0x3fc91a74, 0xdeec508b, 0x3ff921fb, 0x54442d18},	/* 0.19612=f(1.5708)*/
{32, 0,123,__LINE__, 0x3fdfd14d, 0xc015a244, 0x400921fb, 0x54442d18},	/* 0.49715=f(3.14159)*/
{32, 0,123,__LINE__, 0x3fe58b30, 0xfcfd0b72, 0x4012d97c, 0x7f3321d2},	/* 0.673241=f(4.71239)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc03e0000, 0x00000000},	/* nan=f(-30)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc03c4ccc, 0xcccccccd},	/* nan=f(-28.3)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc03a9999, 0x9999999a},	/* nan=f(-26.6)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc038e666, 0x66666667},	/* nan=f(-24.9)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc0373333, 0x33333334},	/* nan=f(-23.2)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc0358000, 0x00000001},	/* nan=f(-21.5)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc033cccc, 0xccccccce},	/* nan=f(-19.8)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc0321999, 0x9999999b},	/* nan=f(-18.1)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc0306666, 0x66666668},	/* nan=f(-16.4)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc02d6666, 0x6666666a},	/* nan=f(-14.7)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc02a0000, 0x00000004},	/* nan=f(-13)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc0269999, 0x9999999e},	/* nan=f(-11.3)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc0233333, 0x33333338},	/* nan=f(-9.6)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc01f9999, 0x999999a3},	/* nan=f(-7.9)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc018cccc, 0xccccccd6},	/* nan=f(-6.2)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc0120000, 0x00000009},	/* nan=f(-4.5)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xc0066666, 0x66666678},	/* nan=f(-2.8)*/
{32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0xbff19999, 0x999999bd},	/* nan=f(-1.1)*/
{32, 0,123,__LINE__, 0xbfcc658a, 0x0d12114e, 0x3fe33333, 0x333332ec},	/* -0.221849=f(0.6)*/
{32, 0,123,__LINE__, 0x3fd7268c, 0x78c4f2d2, 0x40026666, 0x66666654},	/* 0.361728=f(2.3)*/
{32, 0,123,__LINE__, 0x3fe34413, 0x509f79ff, 0x400fffff, 0xffffffee},	/* 0.60206=f(4)*/
{32, 0,123,__LINE__, 0x3fe83020, 0x6f521929, 0x4016cccc, 0xccccccc4},	/* 0.755875=f(5.7)*/
{32, 0,123,__LINE__, 0x3febd0bf, 0x0d1dbbbc, 0x401d9999, 0x99999991},	/* 0.869232=f(7.4)*/
{32, 0,123,__LINE__, 0x3feeb077, 0x9cb71682, 0x40223333, 0x3333332f},	/* 0.959041=f(9.1)*/
{32, 0,123,__LINE__, 0x3ff088e7, 0x5b1ab016, 0x40259999, 0x99999995},	/* 1.03342=f(10.8)*/
{32, 0,123,__LINE__, 0x3ff18cf1, 0x83886481, 0x4028ffff, 0xfffffffb},	/* 1.09691=f(12.5)*/
{32, 0,123,__LINE__, 0x3ff26fc5, 0xe59a1f8d, 0x402c6666, 0x66666661},	/* 1.15229=f(14.2)*/
{32, 0,123,__LINE__, 0x3ff338ec, 0x2e1b69d0, 0x402fcccc, 0xccccccc7},	/* 1.2014=f(15.9)*/
{32, 0,123,__LINE__, 0x3ff3ed9e, 0xb3771c12, 0x40319999, 0x99999997},	/* 1.24551=f(17.6)*/
{32, 0,123,__LINE__, 0x3ff491a4, 0x85d962b8, 0x40334ccc, 0xccccccca},	/* 1.28556=f(19.3)*/
{32, 0,123,__LINE__, 0x3ff527cf, 0x6b505b9f, 0x4034ffff, 0xfffffffd},	/* 1.32222=f(21)*/
{32, 0,123,__LINE__, 0x3ff5b248, 0x2f3ddc51, 0x4036b333, 0x33333330},	/* 1.35603=f(22.7)*/
{32, 0,123,__LINE__, 0x3ff632bf, 0xaadc422c, 0x40386666, 0x66666663},	/* 1.38739=f(24.4)*/
{32, 0,123,__LINE__, 0x3ff6aa8f, 0x3e47819c, 0x403a1999, 0x99999996},	/* 1.41664=f(26.1)*/
{32, 0,123,__LINE__, 0x3ff71ace, 0xb413c934, 0x403bcccc, 0xccccccc9},	/* 1.44404=f(27.8)*/
{32, 0,123,__LINE__, 0x3ff78464, 0x1719126e, 0x403d7fff, 0xfffffffc},	/* 1.46982=f(29.5)*/
{0},};
void test_log10f(int m)   {run_vector_1(m,log10f_vec,(char *)(log10f),"log10f","ff");   }	
